Struct id_vec::id::Id [−][src]
pub struct Id<T> { /* fields omitted */ }Used as a key to access an instance inside a IdVec
Methods
impl<T> Id<T>[src]
impl<T> Id<T>pub fn from_index(index: Index) -> Self[src]
pub fn from_index(index: Index) -> Selfpub fn of<'s>(self, vec: &'s IdVec<T>) -> &'s T[src]
pub fn of<'s>(self, vec: &'s IdVec<T>) -> &'s TConvenience function which allows writing the index first, and the IdVec afterwards.
Example: the_selected_entity.of(entities)
Panics when calling on an invalid id
pub fn of_mut<'s>(self, vec: &'s mut IdVec<T>) -> &'s mut T[src]
pub fn of_mut<'s>(self, vec: &'s mut IdVec<T>) -> &'s mut TConvenience function which allows writing the index first, and the IdVec afterwards.
Example: the_selected_entity.of_mut(entities)
Panics when calling on an invalid id
pub fn try_of<'s>(self, vec: &'s IdVec<T>) -> Option<&'s T>[src]
pub fn try_of<'s>(self, vec: &'s IdVec<T>) -> Option<&'s T>Convenience function which allows writing the index first, and the IdVec afterwards.
Example: the_selected_entity.try_of(entities)
pub fn try_of_mut<'s>(self, vec: &'s mut IdVec<T>) -> Option<&'s mut T>[src]
pub fn try_of_mut<'s>(self, vec: &'s mut IdVec<T>) -> Option<&'s mut T>Convenience function which allows writing the index first, and the IdVec afterwards.
Example: the_selected_entity.try_of_mut(entities)
pub fn index_value(self) -> Index[src]
pub fn index_value(self) -> IndexThe actual integer value for this Id.