Module id_vec::vec [−][src]
Structs
| DrainElements |
Note: always iterates backwards, because it just calls IdMap.pop() |
| ElementIter | |
| IdIter | |
| IdVec |
Inserting elements into this map yields a persistent, type-safe Index to that new element. It does not try to preserve the order of the inserted items. |
| IntoElements |
Note: always iterates backwards, because it just calls IdMap.pop() |
| Iter | |
| OwnedIdIter |